@@ -18,20 +18,20 @@ public class TabularResourceDataView extends DataView {
 
 	public TabularResourceDataView() {
 		super();
-		dataViewType = DataViewType.TABULARRESOURCE;
+		dataViewType = DataViewType.GRID;
 
 	}
 
 	public TabularResourceDataView(TRId trId) {
 		super();
-		dataViewType = DataViewType.TABULARRESOURCE;
+		dataViewType = DataViewType.GRID;
 		this.trId = trId;
 		this.tabName = null;
 	}
 	
 	public TabularResourceDataView(TRId trId, String tabName) {
 		super();
-		dataViewType = DataViewType.TABULARRESOURCE;
+		dataViewType = DataViewType.GRID;
 		this.trId = trId;
 		this.tabName = tabName;
 	}
